function loadWalkthrough(backgroundColor, images, titles, subTitles, btnLoginTitle, btnNextTitle, btnAnonymousTitle, titleFontSize, subTitleFontSize) {
    var walkthroughContainer = "#walkthrough";
    var $walkthrough = $(walkthroughContainer);
    var $pagination = $('<div class="pagination"></div>');
    var $swiperWrapper = $('<div class="swiper-wrapper"></div>');
    // var $bottomBg = $('<div class="bottomBg" style="background:' + backgroundColor + '"></div>');
    var $btnLogin = $('<button class="btn btn-login">Log in</button>');
    var $btnNext = $('<button class="btn btn-next">Next</button>');
    var $btnAnonymous = $('<button class="btn btn-anonymous">Browse app Now</button>');
    var phoneMediaQuery = '';
    var tabletMediaQuery = '@media(min-width: 600px)';
    var isWalkthroughShown = false;

    var btnColor = backgroundColor;
    var wWidth = $('body').width();
    var wHeight = $('body').height();
    var imageSize = (90*wHeight)/100;
    var subTitlePadding = (5*($walkthrough.width() - imageSize))/100;
    var heightButton = (7*wHeight)/100;
    
    $btnLogin.text(btnLoginTitle);
    $btnLogin.css({
    	'height': heightButton,
        'border-color': btnColor,
        'color': btnColor,
    });

    $btnNext.text(btnNextTitle);
    $btnNext.css({
    	'height': heightButton,
        'border-color': btnColor,
        'color': btnColor,
    });
    
    $btnAnonymous.text(btnAnonymousTitle);
    $btnAnonymous.css({
    	'height': heightButton,
        'border-color': btnColor,
        'color': btnColor,
    });

    $walkthrough.addClass('swiper-container');
    $walkthrough.append($btnLogin);
    $walkthrough.append($btnNext);
    $walkthrough.append($btnAnonymous);
    $walkthrough.append($swiperWrapper);
    $walkthrough.append($pagination);


    var buildImageCSS = function(css, imageSelector, image) {
        return css += imageSelector + ' { content:url("' + image + '"); } ';
    }

    var showWalkthrough = function() {
        if (!isWalkthroughShown) {
            isWalkthroughShown = true;
            $walkthrough.show();
            $walkthrough.removeClass('dismiss');
            NativeAPI.onLoadWalkthroughComplete();
        }
    }

    var iOSCSS, tabletCSS;
    iOSCSS = phoneMediaQuery != '' ? phoneMediaQuery + '{' : '';
    tabletCSS = tabletMediaQuery != '' ? tabletMediaQuery + '{' : '';
    if (images) {
        var imageLoadedCount = 0;
        var onLoadImage = function() {
            imageLoadedCount++;
            if (imageLoadedCount >= $swiperWrapper.find('img.hidden').length) {
                showWalkthrough();
            }
        }
        for (var i = 0; i < images.length; i++) {
            var $slideItem = $('<div class="swiper-slide"></div>');

            // TITLE
            var titleItem = titles[i];
            var titleHeight = (10*wHeight)/100;
            var $title = $('<h2 class="css_title" style="font-size:' + titleFontSize + '; height: ' + titleHeight + 'px; line-height: ' + titleHeight + 'px;">' + titleItem +'</h2>');

            var imageItem = images[i];
            var imageClass = 'image' + i;
            var $image = $('<img style="width:' + imageSize + 'px;height:' + imageSize + 'px" src="" class="' + imageClass + '" />');
            $image.attr("src",imageItem);
            
            // SUB-TITLE
            var subTitleItem = subTitles[i];
            var $subTitle = $('<h2 class="css_sub_title" style="padding-left:' + (subTitlePadding + imageSize) + 'px; padding-right: ' + subTitlePadding + 'px ; font-size:' + subTitleFontSize + '">' + subTitleItem + '</h2>');
            
            $slideItem.append($image);
            $slideItem.append($title);
            $slideItem.append($subTitle);

            $swiperWrapper.append($slideItem);

            $subTitle.css('padding-top', imageSize/2 - titleHeight);

            iOSCSS = buildImageCSS(iOSCSS, walkthroughContainer + " ." + imageClass, imageItem);
            tabletCSS = buildImageCSS(tabletCSS, walkthroughContainer + " ." + imageClass, imageItem);
           // $swiperWrapper.append('<img src="' + imageItem + '" class="hidden" style="display: none;">');
            //$swiperWrapper.append('<img src="' + imageItem + '" class="hidden" style="display: none;">');
        }
        $swiperWrapper.find('img').on('load', function() {
            // delay time for initializing necessary components
            var delay=4000;
            setTimeout(function(){
                onLoadImage();
            },delay);
        }).each(function() {
            if(this.complete) {
                $(this).load();
            }
        });
    }
    iOSCSS += phoneMediaQuery != '' ? '}' : '';
    tabletCSS += tabletMediaQuery != '' ? '}' : '';

    var $style = $('style');
    if ($style.length === 0) {
        $style = $('<style></style>')
        $('head').append($style);
    }

    $style.append(iOSCSS);
    $style.append(tabletCSS);

    var processSlideChanged = function(swiper) {
        var slidesLength = swiper.slides.length;
        if (swiper.activeIndex == slidesLength - 1 || slidesLength == 0) { // reach end
            $walkthrough.addClass('end');

            var walkthroughWidth = $walkthrough.outerWidth();
            var btnLoginWidth = $btnLogin.outerWidth();
            var btnLoginOffsetLeft = parseFloat($btnLogin.css('left').replace('px'), 10);
            var translateX = (walkthroughWidth / 2) - (btnLoginWidth / 2) - btnLoginOffsetLeft;
            translateX = 'translateX(' + Math.round(translateX) + 'px)';
//            $btnLogin.css({
//                'transform': translateX,
//                '-webkit-transform': translateX
//            });
        } else {
            $walkthrough.removeClass('end');
            $btnLogin.css({
                'transform': '',
                '-webkit-transform': ''
            });
        }
    }

    var walkthroughSwiper = new Swiper('#walkthrough.swiper-container', {
        mode:'horizontal',
        pagination: '.pagination',
        onSlideChangeStart: processSlideChanged
    });
    var isTouchScreen = 'ontouchstart' in window;
    var clickEvent = isTouchScreen ? 'touchstart' : 'click';
    $btnNext.on(clickEvent, function() {
        walkthroughSwiper.swipeNext();
    });
    $btnAnonymous.on(clickEvent, function() {
    	NativeAPI.openAnonymousMode();
    });
    $btnLogin.on(clickEvent, function() {
        NativeAPI.openLoginPage();
    });
    processSlideChanged(walkthroughSwiper);

    // setTimeout(function () {
    //     showWalkthrough();
    // }, 30000);
}

